pub enum Granularity {
Character,
Line,
}Expand description
The level of precision used for removing old content from a StringRing.
Variants
Character
Remove as few characters as possible (may result in partial lines at the beginning).
Line
Remove entire lines at a time, but always as few lines as possible.
In this mode, if a removed line does not end with a new line character, all content will be deleted
and future input will be discarded until a new line character is encountered.
This is to guarantee that pushing a followed by b is equivalent to pushing a + b.